Struct amazon_sp_messaging::models::attachment::Attachment
source · [−]Expand description
Attachment : Represents a file uploaded to a destination that was created by the createUploadDestinationForResource operation of the Selling Partner API for Uploads.
Fields
upload_destination_id: StringThe identifier of the upload destination. Get this value by calling the createUploadDestinationForResource operation of the Uploads API.
file_name: StringThe name of the file, including the extension. This is the file name that will appear in the message. This does not need to match the file name of the file that you uploaded.
Implementations
sourceimpl Attachment
impl Attachment
sourcepub fn new(upload_destination_id: String, file_name: String) -> Attachment
pub fn new(upload_destination_id: String, file_name: String) -> Attachment
Represents a file uploaded to a destination that was created by the createUploadDestinationForResource operation of the Selling Partner API for Uploads.